@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::EnsureDepakable;
 
-our $DATE = '2016-05-19'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-10-22'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,13 +16,20 @@ use namespace::autoclean;
 sub setup_installer {
     my ($self) = @_;
 
+    if ($ENV{DZIL_ENSUREDEPAKABLE_SKIP}) {
+        $self->log(["Skipping checking depakable because ".
+                        "environment DZIL_ENSUREDEPAKABLE_SKIP is set to true"]);
+        return;
+    }
+
     my $prereqs_hash = $self->zilla->prereqs->as_string_hash;
     my $rr_prereqs = $prereqs_hash->{runtime}{requires} // {};
 
     return unless keys %$rr_prereqs;
 
-    my $res = Module::Depakable::prereq_depakable(
-        prereqs => [grep { $_ ne 'perl' } keys %$rr_prereqs]);
+    my $prereqs = [grep { $_ ne 'perl' } keys %$rr_prereqs];
+    $self->log_debug(["Checking whether prereqs are depakable: %s", $prereqs]);
+    my $res = Module::Depakable::prereq_depakable(prereqs => $prereqs);
     if ($res->[0] != 200) {
         $self->log_fatal(["Distribution not depakable: %s", $res->[1]]);
     }
@@ -44,7 +51,7 @@ Dist::Zilla::Plugin::EnsureDepakable - Make sure that distribution is "depakable
 
 =head1 VERSION
 
-This document describes version 0.002 of Dist::Zilla::Plugin::EnsureDepakable (from Perl distribution Dist-Zilla-Plugin-EnsureDepakable), released on 2016-05-19.
+This document describes version 0.003 of Dist::Zilla::Plugin::EnsureDepakable (from Perl distribution Dist-Zilla-Plugin-EnsureDepakable), released on 2016-10-22.
 
 =head1 SYNOPSIS
 
@@ -63,6 +70,12 @@ See L<Module::Depakable> for more details on the meaning of "depakable".
 
 =for Pod::Coverage .+
 
+=head1 ENVIRONMENT
+
+=head2 DZIL_ENSUREDEPAKABLE_SKIP => bool
+
+Can be set to 1 to skip checking depakable.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-EnsureDepakable>.
